import { useRegisteredDragSource } from "./useRegisteredDragSource";
import { useOptionalFactory } from "../useOptionalFactory";
import { useDragSourceMonitor } from "./useDragSourceMonitor";
import { useDragSourceConnector } from "./useDragSourceConnector";
import { useCollectedProps } from "../useCollectedProps";
import { useConnectDragPreview, useConnectDragSource } from "./connectors";
import { invariant } from "@react-dnd/invariant";
import { computed, unref } from "vue-demi";
/**
 * useDragSource hook
 * @param specArg The drag source specification (object or function, function preferred)
 */ export function useDrag(specArg) {
    var spec = useOptionalFactory(specArg);
    invariant(!unref(spec).begin, "useDrag::spec.begin was deprecated in v14. Replace spec.begin() with spec.item(). (see more here - https://react-dnd.github.io/react-dnd/docs/api/use-drag)");
    var monitor = useDragSourceMonitor();
    var connector = useDragSourceConnector(computed(function() {
        return unref(spec).options;
    }), computed(function() {
        return unref(spec).previewOptions;
    }));
    useRegisteredDragSource(spec, monitor, connector);
    return [
        useCollectedProps(computed(function() {
            return unref(spec).collect || function() {
                return {};
            };
        }), monitor, connector),
        useConnectDragSource(connector, spec),
        useConnectDragPreview(connector, spec), 
    ];
}
